#!/usr/bin/env node

const path = require('path')
const apiMocker = require('mocker-api')
const history = require('connect-history-api-fallback')
const dotenv = require('dotenv')
const dotenvExpand = require('dotenv-expand')

const { createProxyMiddleware }  =  require('http-proxy-middleware')
const  getApp = require( './app')

const log = require('../../utils/log')

// 导入环境变量
dotenvExpand.expand(dotenv.config({ path: path.join(process.cwd(), '.env.production') }))
dotenvExpand.expand(dotenv.config())

// todo：日志服务、多域名代理支持

export default () => {
  const { app, staticServer, config } = getApp()
  const { port, proxy } = config.server

  // 使用 history 解决刷新后报 404 的问题
  app.use(history())

  // 启动静态资源服务
  app.use(staticServer(path.join(config.root, './dist')))

  if (process.env.VUE_APP_USE_MOCKER === 'true') {
    // 临时写法，先跳过签名
    const mocker = apiMocker
    // 启动 mock 服务
    mocker(app, path.join(config.root, './mock/index.js'), {
      proxy: {
        '^/mock': '/mock'
      },
      changeHost: true
    })
  }

  // 启动代理服务
  Object.entries(proxy).forEach(([baseUrl, options]) => {
    app.use(baseUrl, createProxyMiddleware(options))
  })

  // 启动自定义的中间件
  try {
    const middleware = require(`${config.root}/server/index.js`)
    if (middleware) {
      middleware(app)
    }
  } catch (error) {
    log.error(error)
  }

  // 启动
  app.listen(port, () => {
    log.ok(`服务启动成功：http://0.0.0.0:${port}`)
  })
}
