#!/usr/bin/env node

const fs = require('fs-extra')
const inquirer = require('inquirer')
const ora = require('ora')
const {
  checkFolder,
  initGit,
  defaultProjectTips
} = require('./utils.js')
const log = require('../utils/log.js')
const {
  templates,
  packageInfo
} = require('./config.js')

exports.init= (folder) => {
  const root = process.cwd()
  // 工程目录
  const projectFolder = folder ? `${root}/${folder}` : root
  // 工程名称
  const projectName = folder || root.split('/').pop()

  // 清空判断
  checkFolder(projectFolder, () => {
    // 工程类型
    inquirer.prompt({
      type: 'list',
      name: 'type',
      message: '请选择工程类型：',
      choices: templates
    }).then(project => {

      // 变量替换
      inquirer.prompt(packageInfo).then(pkg => {

        const spinner = ora('工程初始化中，请稍等').start()

        initGit(project.type, projectFolder, () => {
          spinner.text = '下载完成，开始生成 package.json'

          // 替换 package.json 中 version、description 和 name 的值
          const pkgPath = `${projectFolder}/package.json`
          fs.writeFileSync(
            pkgPath,
            JSON.stringify({
              ...require(pkgPath), ...pkg,
              name: projectName
            }, null, 2)
          )

          spinner.stop()
          log.ok('工程初始化成功', false)
          defaultProjectTips(folder)
        })

      })
    })
  })
}

